// Importing D3.js Components
import {select, csv, scaleLinear, axisLeft, axisBottom, format, extent} from 'd3';
// This selects the SVG element in the HTML document and assigns it to the 'svg' constant.
const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');
// The render function is defined to create the scatter plot visualization using the provided data.
function render (data) {
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Potential';
  const yValue = d => d.weight;
  const yAxisLabel = 'Weightofthevehicle';
  const circleRadius = 10;
  const title = 'Vehicle: potential vs. Weightofvehicle';
  
  const margin = {top: 60, right: 30, bottom: 80, left: 140};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
 // The function sets up xScale and yScale using scaleLinear() to map data values to the corresponding positions on the chart. 
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
	
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice()
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`)
 // The code creates the y-axis using axisLeft() and the x-axis using axisBottom(). 
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
 // Two SVG groups ('g' elements) are appended to the SVG. These groups will contain the y-axis and x-axis elements, respectively. 
  const yAxisG = g.append('g')
    .call(yAxis)
 // Text labels are added to the y-axis and x-axis, displaying the labels 'Weightofthevehicle' and 'Potential', respectively 	
 yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.text(yAxisLabel)
  	.attr('fill', 'red')
  	.attr('x', -innerHeight / 2)
  	.attr('y', -95)
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15)
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  	
  xAxisG.select('.domain').remove();
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.text(xAxisLabel)
  	.attr('fill', 'red')
  	.attr('x', innerWidth / 2)
  	.attr('y', 75)
  
  g.selectAll('circle')
    .data(data)
  	.enter()
  		.append('circle')
  			.attr('cy', d => yScale(yValue(d)))
  			.attr('cx', d => xScale(xValue(d)))
  			.attr('r', circleRadius)
  
  g.append('text')
  .attr('class', 'title')
  .attr('y', -10)
  	.text(title)
}

csv('https://gist.githubusercontent.com/Swapna1915/6c0e991ba9d1c9369de1eb7112bacdb4/raw/f82770d3788306b5387cfebd1072df505e1ca271/vehicle%2520potential.csv')
  .then(data => {
  const numberedData = data.map(d => ({...d, mpg: +d.mpg, cylinders: +d.cylinders, displacement: +d.displacement, horsepower: +d.horsepower, weight: +d.weight, acceleration: +d.acceleration, year: +d.year}))
	render(numberedData);
})




